@@ -5,6 +5,7 @@ use tokio::sync::oneshot::Sender;
 
 use crate::response::FeroxResponse;
 use crate::{
+    event_handlers::Handles,
     message::FeroxMessage,
     statistics::{StatError, StatField},
     traits::FeroxFilter,
@@ -78,4 +79,8 @@ pub enum Command {
 
     /// Break out of the (infinite) mpsc receive loop
     Exit,
+
+    /// Give a handler access to an Arc<Handles> instance after the handler has
+    /// already been initialized
+    AddHandles(Arc<Handles>),
 }
