@@ -124,13 +124,12 @@ impl Requester {
 
     /// limit the number of requests per second
     pub async fn limit(&self) -> Result<()> {
-        self.rate_limiter
-            .read()
-            .await
-            .as_ref()
-            .unwrap()
-            .acquire_one()
-            .await?;
+        let guard = self.rate_limiter.read().await;
+
+        if guard.is_some() {
+            guard.as_ref().unwrap().acquire_one().await?;
+        }
+
         Ok(())
     }
 
